@@ -13,19 +13,16 @@
 #ifndef ROOM_H
 #define ROOM_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
-#include <qstring.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
+#include <QString>
+#include <QList>
+#include <QStringList>
 
 class Room;
 class Rules;
 
-class RoomsList: public QPtrList<Room>
-{
-	int compareItems(QPtrCollection::Item, QPtrCollection::Item);
-};
+typedef QList<Room*> RoomsList;
 
 /**
 This class represents a room
@@ -35,25 +32,25 @@ This class represents a room
 class Room{ /*classroom :-)*/
 public:
 	QString name;
-	QString type;
+	//QString type;
 	int capacity;
-	QStringList equipments;
+	//QStringList equipments;
 	/**
 	If empty string, it is ignored
 	*/
-	QString building; 
+	//QString building; 
 	
 	/**
 	Internal. If -1, it is ignored
 	*/
-	int buildingIndex;
+	//int buildingIndex;
 
 	Room();
 	~Room();
 	
-	void addEquipment(const QString& equipmentName);
+	/*void addEquipment(const QString& equipmentName);
 	void removeEquipment(const QString& equipmentName);
-	bool searchEquipment(const QString& equipmentName);
+	bool searchEquipment(const QString& equipmentName);*/
 	
 	void computeInternalStructure(Rules& r);
 
@@ -63,4 +60,6 @@ public:
 	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
+int roomsAscending(const Room* r1, const Room* r2);
+
 #endif
