@@ -13,18 +13,15 @@
 #ifndef SUBJECTTAG_H
 #define SUBJECTTAG_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
 #include <qstring.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 
 class SubjectTag;
 class Rules;
 
-class SubjectTagsList: public QPtrList<SubjectTag>
-{
-	int compareItems(QPtrCollection::Item, QPtrCollection::Item);
-};
+typedef QList<SubjectTag*> SubjectTagsList;
 
 /**
 This class represents a subject tag
@@ -43,4 +40,6 @@ public:
 	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
+int subjectTagsAscending(const SubjectTag* st1, const SubjectTag* st2);
+
 #endif
