@@ -25,14 +25,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef TIMECONSTRAINT_H
 #define TIMECONSTRAINT_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
-#include <qstring.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
+#include <QString>
+#include <QList>
+#include <QStringList>
 
 class Rules;
-class TimeChromosome;
+class Solution;
 class TimeConstraint;
 class Activity;
 class Teacher;
@@ -40,43 +40,43 @@ class Subject;
 class SubjectTag;
 class StudentsSet;
 
-typedef QPtrList<TimeConstraint> TimeConstraintsList;
+typedef QList<TimeConstraint*> TimeConstraintsList;
 
 const int CONSTRAINT_GENERIC_TIME										=0;
 
 const int CONSTRAINT_BASIC_COMPULSORY_TIME								=1;
+const int CONSTRAINT_BREAK												=2;
 
-const int CONSTRAINT_TEACHER_NOT_AVAILABLE								=2;
-const int CONSTRAINT_TEACHERS_MAX_HOURS_CONTINUOUSLY					=3;
-const int CONSTRAINT_TEACHERS_SUBGROUPS_MAX_HOURS_DAILY					=4;
-const int CONSTRAINT_TEACHERS_NO_GAPS									=5;
-const int CONSTRAINT_TEACHERS_MAX_HOURS_DAILY							=6;
-const int CONSTRAINT_TEACHER_MAX_DAYS_PER_WEEK							=7;
-
-const int CONSTRAINT_BREAK												=8;
+const int CONSTRAINT_TEACHER_NOT_AVAILABLE								=3;
+const int CONSTRAINT_TEACHERS_MAX_HOURS_DAILY							=4;
+const int CONSTRAINT_TEACHER_MAX_DAYS_PER_WEEK							=5;
+const int CONSTRAINT_TEACHERS_MAX_GAPS_PER_WEEK							=6;
+const int CONSTRAINT_TEACHER_MAX_GAPS_PER_WEEK							=7;
+const int CONSTRAINT_TEACHER_MAX_HOURS_DAILY							=8;
 
 const int CONSTRAINT_STUDENTS_EARLY										=9;
 const int CONSTRAINT_STUDENTS_SET_NOT_AVAILABLE							=10;
-const int CONSTRAINT_STUDENTS_N_HOURS_DAILY								=11;
-const int CONSTRAINT_STUDENTS_SET_N_HOURS_DAILY							=12;
-const int CONSTRAINT_STUDENTS_NO_GAPS									=13;
-const int CONSTRAINT_STUDENTS_SET_NO_GAPS								=14;
-const int CONSTRAINT_STUDENTS_SET_INTERVAL_MAX_DAYS_PER_WEEK			=15;
+const int CONSTRAINT_STUDENTS_NO_GAPS									=11;
+const int CONSTRAINT_STUDENTS_SET_NO_GAPS								=12;
+const int CONSTRAINT_STUDENTS_SET_EARLY									=13;
+const int CONSTRAINT_STUDENTS_MAX_HOURS_DAILY							=14;
+const int CONSTRAINT_STUDENTS_SET_MAX_HOURS_DAILY						=15;
+const int CONSTRAINT_STUDENTS_MIN_HOURS_DAILY							=16;
+const int CONSTRAINT_STUDENTS_SET_MIN_HOURS_DAILY						=17;
 
-const int CONSTRAINT_ACTIVITY_PREFERRED_TIME							=16;
-const int CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME						=17;
-const int CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING							=18;
-const int CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES						=19;
-const int CONSTRAINT_ACTIVITY_PREFERRED_TIMES							=20;
-const int CONSTRAINT_ACTIVITY_ENDS_DAY									=21;
-const int CONSTRAINT_2_ACTIVITIES_CONSECUTIVE							=22;
-const int CONSTRAINT_2_ACTIVITIES_ORDERED								=23;
-const int CONSTRAINT_2_ACTIVITIES_GROUPED								=24;
-const int CONSTRAINT_ACTIVITIES_PREFERRED_TIMES							=25;
-const int CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR						=26;
+const int CONSTRAINT_ACTIVITY_PREFERRED_TIME							=18;
+const int CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME						=19;
+const int CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING							=20;
+const int CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES						=21;
+const int CONSTRAINT_ACTIVITY_PREFERRED_TIMES							=22;
+const int CONSTRAINT_ACTIVITIES_PREFERRED_TIMES							=23;
+const int CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR						=24;
+const int CONSTRAINT_2_ACTIVITIES_CONSECUTIVE							=25;
 
-const int CONSTRAINT_TEACHERS_SUBJECT_TAGS_MAX_HOURS_CONTINUOUSLY		=27;
-const int CONSTRAINT_TEACHERS_SUBJECT_TAG_MAX_HOURS_CONTINUOUSLY		=28;
+const int CONSTRAINT_ACTIVITY_ENDS_STUDENTS_DAY							=26;
+
+const int CONSTRAINT_TEACHERS_MIN_HOURS_DAILY							=27;
+const int CONSTRAINT_TEACHER_MIN_HOURS_DAILY							=28;
 
 /**
 This class represents a time constraint
@@ -84,9 +84,9 @@ This class represents a time constraint
 class TimeConstraint{
 public:
 	/**
-	The weight of this constraint
+	The percentage weight of this constraint, 100% compulsory, 0% non-compulsory
 	*/
-	double weight;
+	double weightPercentage;
 
 	/**
 	Specifies the type of this constraint (using the above constants).
@@ -96,7 +96,7 @@ public:
 	/**
 	True for mandatory constraints, false for non-mandatory constraints.
 	*/
-	bool compulsory;
+	//bool compulsory;
 
 	/**
 	Dummy constructor - needed for the static array of constraints.
@@ -107,13 +107,13 @@ public:
 	virtual ~TimeConstraint()=0;
 
 	/**
+	DEPRECATED COMMENT
 	Constructor - please note that the maximum allowed weight is 100.0
 	The reason: unallocated activities must have very big conflict weight,
 	and any other restrictions must have much more lower weight,
 	so that the timetable can evolve when starting with uninitialized activities.
-	Also, it is preferred that you use integer weights for the moment.
 	*/
-	TimeConstraint(double w, bool c);
+	TimeConstraint(double wp);
 
 	/**
 	The function that calculates the fitness of a chromosome, according to this
@@ -121,7 +121,7 @@ public:
 	If conflictsString!=NULL,
 	it will be initialized with a text explaining where this restriction is broken.
 	*/
-	virtual int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL)=0;
+	virtual double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>& dl, QString* conflictsString=NULL)=0;
 
 	/**
 	Returns an XML description of this constraint
@@ -180,7 +180,7 @@ class ConstraintBasicCompulsoryTime: public TimeConstraint{
 public:
 	ConstraintBasicCompulsoryTime();
 
-	ConstraintBasicCompulsoryTime(double w);
+	ConstraintBasicCompulsoryTime(double wp);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -190,7 +190,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -242,7 +242,7 @@ public:
 
 	ConstraintTeacherNotAvailable();
 
-	ConstraintTeacherNotAvailable(double w, bool c, const QString& tn, int day, int start_hour, int end_hour);
+	ConstraintTeacherNotAvailable(double wp, const QString& tn, int day, int start_hour, int end_hour);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -252,7 +252,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -306,7 +306,7 @@ public:
 
 	ConstraintStudentsSetNotAvailable();
 
-	ConstraintStudentsSetNotAvailable(double w, bool c, const QString& sn, int day, int start_hour, int end_hour);
+	ConstraintStudentsSetNotAvailable(double wp, const QString& sn, int day, int start_hour, int end_hour);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -316,7 +316,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -330,6 +330,7 @@ public:
 };
 
 /**
+DEPRECATED COMMENT
 This is a constraint.
 It aims at scheduling a set of activities at the same starting time.
 The number of conflicts is considered the sum of differences
@@ -337,7 +338,7 @@ in the scheduling time for all pairs of activities.
 The difference in the scheduling time for a pair of
 activities is considered the sum between the difference in the starting
 day and the difference in the starting hour.
-TODO: Weekly activities are counted as two and bi-weekly activities as one
+TODO: Weekly activities are counted as two and fortnightly activities as one
 (really necessary?).
 IMPORTANT: Starting with version 3.2.3, the compulsory constraints of this kind
 implement chromosome repairing, so no conflicts will be reported
@@ -370,7 +371,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities' id-s.
 	*/
-	ConstraintActivitiesSameStartingTime(double w, bool c, int n_act, const int act[]);
+	ConstraintActivitiesSameStartingTime(double wp, int n_act, const int act[]);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -380,7 +381,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	/**
 	Removes useless activities from the _activities and activitiesId array
@@ -432,7 +433,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintActivitiesNotOverlapping(double w, bool c, int n_act, const int act[]);
+	ConstraintActivitiesNotOverlapping(double wp, int n_act, const int act[]);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -442,7 +443,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	/**
 	Removes useless activities from the _activities array
@@ -467,6 +468,8 @@ have a minimum of N days between any two of them.
 */
 class ConstraintMinNDaysBetweenActivities: public TimeConstraint{
 public:
+	bool consecutiveIfSameDay;
+
 	/**
 	The number of activities involved in this constraint
 	*/
@@ -500,7 +503,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintMinNDaysBetweenActivities(double w, bool c, int n_act, const int act[], int n);
+	ConstraintMinNDaysBetweenActivities(double wp, bool adjacentIfBroken, int n_act, const int act[], int n);
 
 	/**
 	Comparison operator - to be sure that we do not introduce duplicates
@@ -515,7 +518,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	/**
 	Removes useless activities from the _activities array
@@ -533,42 +536,6 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-This is a constraint, aimed at obtaining timetables
-which do not allow more than X hours in a row for any teacher
-*/
-class ConstraintTeachersMaxHoursContinuously: public TimeConstraint{
-public:
-	/**
-	The maximum hours continuously
-	*/
-	int maxHoursContinuously;
-
-	ConstraintTeachersMaxHoursContinuously();
-
-	ConstraintTeachersMaxHoursContinuously(double w, bool c, int maxhours);
-
-	QString getXmlDescription(Rules& r);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
 /**
 This is a constraint, aimed at obtaining timetables
 which do not allow more than X hours in a day for any teacher
@@ -582,7 +549,7 @@ public:
 
 	ConstraintTeachersMaxHoursDaily();
 
-	ConstraintTeachersMaxHoursDaily(double w, bool c, int maxhours);
+	ConstraintTeachersMaxHoursDaily(double wp, int maxhours);
 
 	QString getXmlDescription(Rules& r);
 
@@ -592,7 +559,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -605,31 +572,30 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-A constraint aimed at obtaining timetables
-which do not allow for a certain teacher and a certain
-subgroup more than X hours per day
-*/
-class ConstraintTeachersSubgroupsMaxHoursDaily: public TimeConstraint{
+class ConstraintTeacherMaxHoursDaily: public TimeConstraint{
 public:
 	/**
-	The maximum allowed hours daily
+	The maximum hours daily
 	*/
 	int maxHoursDaily;
+	
+	QString teacherName;
+	
+	int teacher_ID;
 
-	ConstraintTeachersSubgroupsMaxHoursDaily();
+	ConstraintTeacherMaxHoursDaily();
 
-	ConstraintTeachersSubgroupsMaxHoursDaily(double w, bool c, int maxhours);
-
-	bool computeInternalStructure(Rules& r);
+	ConstraintTeacherMaxHoursDaily(double wp, int maxhours, const QString& teacher);
 
 	QString getXmlDescription(Rules& r);
 
+	bool computeInternalStructure(Rules& r);
+
 	QString getDescription(Rules& r);
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -658,7 +624,7 @@ public:
 	/**
 	The teacher's name
 	*/
-	QString teacher;
+	QString teacherName;
 
 	/**
 	The teacher's id, or index in the rules
@@ -667,7 +633,7 @@ public:
 
 	ConstraintTeacherMaxDaysPerWeek();
 
-	ConstraintTeacherMaxDaysPerWeek(double w, bool c, int maxnd, QString t);
+	ConstraintTeacherMaxDaysPerWeek(double wp, int maxnd, QString t);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -677,7 +643,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -714,7 +680,7 @@ public:
 
 	ConstraintBreak();
 
-	ConstraintBreak(double w, bool c, int day, int start_hour, int end_hour);
+	ConstraintBreak(double wp, int day, int start_hour, int end_hour);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -724,7 +690,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -747,7 +713,7 @@ class ConstraintStudentsNoGaps: public TimeConstraint{
 public:
 	ConstraintStudentsNoGaps();
 
-	ConstraintStudentsNoGaps(double w, bool c);
+	ConstraintStudentsNoGaps(double wp);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -757,7 +723,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -796,7 +762,7 @@ public:
 
 	ConstraintStudentsSetNoGaps();
 
-	ConstraintStudentsSetNoGaps(double w, bool c, const QString& st );
+	ConstraintStudentsSetNoGaps(double wp, const QString& st );
 
 	bool computeInternalStructure(Rules& r);
 
@@ -806,7 +772,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -819,18 +785,13 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-This is a constraint. It adds, to the fitness of the chromosome, a
-conflicts factor computed from the gaps existing in the timetable
-(regarding the teachers). The overall result is a timetable having
-less gaps for the teachers.
-*/
-class ConstraintTeachersNoGaps: public TimeConstraint{
+class ConstraintTeachersMaxGapsPerWeek: public TimeConstraint{
 public:
+	int maxGaps;	
 
-	ConstraintTeachersNoGaps();
+	ConstraintTeachersMaxGapsPerWeek();
 
-	ConstraintTeachersNoGaps(double w, bool c);
+	ConstraintTeachersMaxGapsPerWeek(double wp, int maxGaps);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -840,7 +801,40 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+class ConstraintTeacherMaxGapsPerWeek: public TimeConstraint{
+public:
+	int maxGaps;
+	
+	QString teacherName;
+	
+	int teacherIndex;
+
+	ConstraintTeacherMaxGapsPerWeek();
+
+	ConstraintTeacherMaxGapsPerWeek(double wp, QString tn, int maxGaps);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getXmlDescription(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -858,7 +852,7 @@ This is a constraint. It adds, to the fitness of
 the chromosome, a fitness factor that is related to how early
 the students begin their courses. The result is a timetable
 having more activities scheduled at the beginning of the day.
-IMPORTANT: biweekly activities are treated as weekly ones,
+IMPORTANT: fortnightly activities are treated as weekly ones,
 for speed and because in normal situations this does not matter.
 */
 class ConstraintStudentsEarly: public TimeConstraint{
@@ -866,7 +860,7 @@ public:
 
 	ConstraintStudentsEarly();
 
-	ConstraintStudentsEarly(double w, bool compulsory);
+	ConstraintStudentsEarly(double wp);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -876,7 +870,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -889,26 +883,130 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-This is a constraint. 
-The result is a timetable respecting the condition that the students
-must not have too little or too much hours in a day.
-*/
-class ConstraintStudentsNHoursDaily: public TimeConstraint{
+class ConstraintStudentsSetEarly: public TimeConstraint{
 public:
 	/**
-	The number of maximum allowed hours per day (-1 for don't care)
+	The name of the students
 	*/
+	QString students;
+
+	/**
+	The number of subgroups involved in this restriction
+	*/
+	int nSubgroups;
+
+	/**
+	The subgroups involved in this restriction
+	*/
+	int subgroups[MAX_SUBGROUPS_PER_CONSTRAINT];
+
+	ConstraintStudentsSetEarly();
+
+	ConstraintStudentsSetEarly(double wp, const QString& students);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getXmlDescription(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+class ConstraintStudentsMaxHoursDaily: public TimeConstraint{
+public:
+	int maxHoursDaily;
+
+	ConstraintStudentsMaxHoursDaily();
+
+	ConstraintStudentsMaxHoursDaily(double wp, int maxnh);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getXmlDescription(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+class ConstraintStudentsSetMaxHoursDaily: public TimeConstraint{
+public:
 	int maxHoursDaily;
 
 	/**
-	The number of minimum allowed hours per day (-1 for don't care)
+	The students set name
 	*/
+	QString students;
+
+	//internal variables
+
+	/**
+	The number of subgroups
+	*/
+	int nSubgroups;
+
+	/**
+	The subgroups
+	*/
+	int subgroups[MAX_SUBGROUPS_PER_CONSTRAINT];
+
+	ConstraintStudentsSetMaxHoursDaily();
+
+	ConstraintStudentsSetMaxHoursDaily(double wp, int maxnh, QString s);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getXmlDescription(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+class ConstraintStudentsMinHoursDaily: public TimeConstraint{
+public:
 	int minHoursDaily;
 
-	ConstraintStudentsNHoursDaily();
+	ConstraintStudentsMinHoursDaily();
 
-	ConstraintStudentsNHoursDaily(double w, bool c, int maxnh, int minnh);
+	ConstraintStudentsMinHoursDaily(double wp, int minnh);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -918,7 +1016,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -931,21 +1029,8 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-This is a constraint. 
-The result is a timetable respecting the condition that this students set
-must not have too little or too much hours in a day.
-*/
-class ConstraintStudentsSetNHoursDaily: public TimeConstraint{
+class ConstraintStudentsSetMinHoursDaily: public TimeConstraint{
 public:
-	/**
-	The number of maximum allowed hours per day (-1 for don't care)
-	*/
-	int maxHoursDaily;
-
-	/**
-	The number of minimum allowed hours per day (-1 for don't care)
-	*/
 	int minHoursDaily;
 
 	/**
@@ -965,9 +1050,9 @@ public:
 	*/
 	int subgroups[MAX_SUBGROUPS_PER_CONSTRAINT];
 
-	ConstraintStudentsSetNHoursDaily();
+	ConstraintStudentsSetMinHoursDaily();
 
-	ConstraintStudentsSetNHoursDaily(double w, bool c, int maxnh, int minnh, QString s);
+	ConstraintStudentsSetMinHoursDaily(double wp, int minnh, QString s);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -977,73 +1062,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
-/**
-This is a custom constraint.
-For a certain students set:
-The purpose is that a certain interval not be scheduled more than n times in a week
-(for example, there must be only 2 occupied intervals between hours 3 and 6,
-which might be on Monday and on Tuesday.
-*/
-class ConstraintStudentsSetIntervalMaxDaysPerWeek: public TimeConstraint{
-public:
-	/**
-	The start hour
-	*/
-	int h1;
-
-	/**
-	The end hour
-	*/
-	int h2;
-
-	/**
-	The name of the students
-	*/
-	QString students;
-
-	/**
-	The max. number of intervals
-	*/
-	int n;
-
-	//internal variables
-
-	/**
-	The number of subgroups involved in this restriction
-	*/
-	int nSubgroups;
-
-	/**
-	The subgroups involved in this restriction
-	*/
-	int subgroups[MAX_SUBGROUPS_PER_CONSTRAINT];
-
-	ConstraintStudentsSetIntervalMaxDaysPerWeek();
-
-	ConstraintStudentsSetIntervalMaxDaysPerWeek(double w, bool c, const QString& sn, int start_hour, int end_hour, int n_intervals);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getXmlDescription(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1088,7 +1107,7 @@ public:
 
 	ConstraintActivityPreferredTime();
 
-	ConstraintActivityPreferredTime(double w, bool c, int actId, int d, int h);
+	ConstraintActivityPreferredTime(double wp, int actId, int d, int h);
 
 	/**
 	Comparison operator - to be sure that we do not introduce duplicates
@@ -1103,7 +1122,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1151,7 +1170,7 @@ public:
 
 	ConstraintActivityPreferredTimes();
 
-	ConstraintActivityPreferredTimes(double w, bool c, int actId, int nPT, int d[], int h[]);
+	ConstraintActivityPreferredTimes(double wp, int actId, int nPT, int d[], int h[]);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1161,225 +1180,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
-/**
-This is a constraint.
-It returns a conflicts factor that increases with the number of lessons
-that follow after this activity (in the same day).
-*/
-class ConstraintActivityEndsDay: public TimeConstraint{
-public:
-	/**
-	Activity id
-	*/
-	int activityId;
-
-	//internal variables
-	/**
-	The index of the activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int activityIndex;
-
-	ConstraintActivityEndsDay();
-
-	ConstraintActivityEndsDay(double w, bool c, int actId);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getXmlDescription(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
-/**
-This is a time constraint.
-PURPOSE: you have two activities that you want to schedule one after
-the other, in the same day. Order is important.
-It adds, to the fitness of the chromosome, a value that
-grows as the 2 activities are scheduled farther one from each other.
-For the moment, fitness factor increases with one unit for every additional 
-hour and one unit for every day (the optimal being 0 - when the starting time
-of the second activity is the ending time of the first one).
-*/
-class Constraint2ActivitiesConsecutive: public TimeConstraint{
-public:
-	/**
-	First activity id
-	*/
-	int firstActivityId;
-
-	/**
-	Second activity id
-	*/
-	int secondActivityId;
-
-	//internal variables
-	/**
-	The index of the first activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int firstActivityIndex;
-
-	/**
-	The index of the second activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int secondActivityIndex;
-
-	Constraint2ActivitiesConsecutive();
-
-	Constraint2ActivitiesConsecutive(double w, bool c, int firstActId, int secondActId);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getXmlDescription(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
-/**
-This is a time constraint.
-PURPOSE: you have two activities that you want to schedule one after
-the other, not necessarily in the same day or adjacent. Order is important.
-It adds, to the fitness of the chromosome, the weight multimplied with 2 if the first
-activity is weekly (not bi-weekly) and with again with 2 if the second activity
-is weekly, if the condition is broken.
-*/
-class Constraint2ActivitiesOrdered: public TimeConstraint{
-public:
-	/**
-	First activity id
-	*/
-	int firstActivityId;
-
-	/**
-	Second activity id
-	*/
-	int secondActivityId;
-
-	//internal variables
-	/**
-	The index of the first activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int firstActivityIndex;
-
-	/**
-	The index of the second activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int secondActivityIndex;
-
-	Constraint2ActivitiesOrdered();
-
-	Constraint2ActivitiesOrdered(double w, bool c, int firstActId, int secondActId);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getXmlDescription(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
-
-	bool isRelatedToActivity(Activity* a);
-	
-	bool isRelatedToTeacher(Teacher* t);
-
-	bool isRelatedToSubject(Subject* s);
-
-	bool isRelatedToSubjectTag(SubjectTag* s);
-	
-	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
-};
-
-/**
-This is a time constraint.
-PURPOSE: you have two activities that you want to schedule one after
-the other, in the same day. Order is not important.
-It adds, to the fitness of the chromosome, a value that
-grows as the 2 activities are scheduled farther one from each other.
-For the moment, fitness factor increases with one unit for every additional
-hour and one unit for every day.
-(For hours, we have a 0 as minimum if the activities
-are OK, a positive constant value if they overlap and a positive
-increasing value if they are not touching.
-For days - we have a simple absolute difference).
-*/
-class Constraint2ActivitiesGrouped: public TimeConstraint{
-public:
-	/**
-	First activity id
-	*/
-	int firstActivityId;
-
-	/**
-	Second activity id
-	*/
-	int secondActivityId;
-
-	//internal variables
-	/**
-	The index of the first activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int firstActivityIndex;
-
-	/**
-	The index of the second activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
-	*/
-	int secondActivityIndex;
-
-	Constraint2ActivitiesGrouped();
-
-	Constraint2ActivitiesGrouped(double w, bool c, int firstActId, int secondActId);
-
-	bool computeInternalStructure(Rules& r);
-
-	QString getXmlDescription(Rules& r);
-
-	QString getDescription(Rules& r);
-
-	QString getDetailedDescription(Rules& r);
-
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1451,7 +1252,7 @@ public:
 
 	ConstraintActivitiesPreferredTimes();
 
-	ConstraintActivitiesPreferredTimes(double w, bool c, QString te,
+	ConstraintActivitiesPreferredTimes(double wp, QString te,
 		QString st, QString su, QString sut, int nPT, int d[], int h[]);
 
 	bool computeInternalStructure(Rules& r);
@@ -1462,7 +1263,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1482,7 +1283,7 @@ The number of conflicts is considered the sum of differences
 in the scheduling time for all pairs of activities.
 The difference in the scheduling time for a pair of
 activities is considered the difference in the starting hour.
-TODO: Weekly activities are counted as two and bi-weekly activities as one
+TODO: Weekly activities are counted as two and fortnightly activities as one
 (really necessary?).
 IMPORTANT: The compulsory constraints of this kind
 implement chromosome repairing, so no conflicts will be reported
@@ -1515,7 +1316,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities' id-s.
 	*/
-	ConstraintActivitiesSameStartingHour(double w, bool c, int n_act, const int act[]);
+	ConstraintActivitiesSameStartingHour(double wp, int n_act, const int act[]);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1525,7 +1326,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	/**
 	Removes useless activities from the _activities array
@@ -1543,22 +1344,32 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-A constraint aimed at obtaining timetables
-which do not allow for a certain teacher (from all teachers) and 
-a certain subject tag (from all subject tags) more 
-than max hours countinuously
-*/
-class ConstraintTeachersSubjectTagsMaxHoursContinuously: public TimeConstraint{
+class Constraint2ActivitiesConsecutive: public TimeConstraint{
 public:
 	/**
-	The maximum allowed hours continuously
+	First activity id
 	*/
-	int maxHoursContinuously;
-	
-	ConstraintTeachersSubjectTagsMaxHoursContinuously();
+	int firstActivityId;
 
-	ConstraintTeachersSubjectTagsMaxHoursContinuously(double w, bool c, int maxhours);
+	/**
+	Second activity id
+	*/
+	int secondActivityId;
+
+	//internal variables
+	/**
+	The index of the first activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
+	*/
+	int firstActivityIndex;
+
+	/**
+	The index of the second activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
+	*/
+	int secondActivityIndex;
+
+	Constraint2ActivitiesConsecutive();
+
+	Constraint2ActivitiesConsecutive(double wp, int firstActId, int secondActId);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1568,7 +1379,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1581,31 +1392,22 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
-/**
-A constraint aimed at obtaining timetables
-which do not allow for a certain teacher from all teachers and 
-a certain subject tag more than max hours countinuously
-*/
-class ConstraintTeachersSubjectTagMaxHoursContinuously: public TimeConstraint{
+class ConstraintActivityEndsStudentsDay: public TimeConstraint{
 public:
 	/**
-	The maximum allowed hours continuously
+	Activity id
 	*/
-	int maxHoursContinuously;
-	
-	/**
-	The subject tag
-	*/
-	QString subjectTagName;
-	
-	/**
-	The subject tag index
-	*/
-	int subjectTagIndex;
-	
-	ConstraintTeachersSubjectTagMaxHoursContinuously();
+	int activityId;
 
-	ConstraintTeachersSubjectTagMaxHoursContinuously(double w, bool c, int maxhours, const QString& subjecttag);
+	//internal variables
+	/**
+	The index of the activity in the rules (from 0 to rules.nActivities-1) - it is not the id of the activity
+	*/
+	int activityIndex;
+
+	ConstraintActivityEndsStudentsDay();
+
+	ConstraintActivityEndsStudentsDay(double wp, int actId);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1615,7 +1417,7 @@ public:
 
 	QString getDetailedDescription(Rules& r);
 
-	int fitness(TimeChromosome& c, Rules& r, QString* conflictsString=NULL);
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
 
 	bool isRelatedToActivity(Activity* a);
 	
@@ -1628,4 +1430,73 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 };
 
+class ConstraintTeachersMinHoursDaily: public TimeConstraint{
+public:
+	/**
+	The minimum hours daily
+	*/
+	int minHoursDaily;
+
+	ConstraintTeachersMinHoursDaily();
+
+	ConstraintTeachersMinHoursDaily(double wp, int minhours);
+
+	QString getXmlDescription(Rules& r);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+class ConstraintTeacherMinHoursDaily: public TimeConstraint{
+public:
+	/**
+	The minimum hours daily
+	*/
+	int minHoursDaily;
+	
+	QString teacherName;
+	
+	int teacher_ID;
+
+	ConstraintTeacherMinHoursDaily();
+
+	ConstraintTeacherMinHoursDaily(double wp, int minhours, const QString& teacher);
+
+	QString getXmlDescription(Rules& r);
+
+	bool computeInternalStructure(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToSubjectTag(SubjectTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+};
+
+
 #endif
