@@ -21,31 +21,138 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 AddConstraintMinNDaysBetweenActivitiesForm::AddConstraintMinNDaysBetweenActivitiesForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+	
 	updateActivitiesListBox();
 	
 	minDaysSpinBox->setMinValue(1);
+	minDaysSpinBox->setValue(1);
 	minDaysSpinBox->setMaxValue(gt.rules.nDaysPerWeek-1);
+
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	subjectTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* st=gt.rules.subjectTagsList[i];
+		subjectTagsComboBox->insertItem(st->name);
+	}
+	subjectTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
+
+	selectedActivitiesListBox->clear();
+	this->selectedActivitiesList.clear();
+
+	filterChanged();
 }
 
 AddConstraintMinNDaysBetweenActivitiesForm::~AddConstraintMinNDaysBetweenActivitiesForm()
 {
 }
 
+bool AddConstraintMinNDaysBetweenActivitiesForm::filterOk(Activity* act)
+{
+	QString tn=teachersComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=subjectTagsComboBox->currentText();
+	int ok=true;
+
+	//teacher
+	if(tn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+			if(*it == tn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+
+	//subject
+	if(sbn!="" && sbn!=act->subjectName)
+		ok=false;
+		
+	//subject tag
+	if(sbtn!="" && sbtn!=act->subjectTagName)
+		ok=false;
+		
+	//students
+	if(stn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+			if(*it == stn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+	
+	return ok;
+}
+
+void AddConstraintMinNDaysBetweenActivitiesForm::filterChanged()
+{
+	this->updateActivitiesListBox();
+}
+
 void AddConstraintMinNDaysBetweenActivitiesForm::updateActivitiesListBox()
 {
 	activitiesListBox->clear();
-	selectedActivitiesListBox->clear();
+	//selectedActivitiesListBox->clear();
 
 	this->activitiesList.clear();
-	this->selectedActivitiesList.clear();
+	//this->selectedActivitiesList.clear();
 
-	for(Activity* ac=gt.rules.activitiesList.first(); ac; ac=gt.rules.activitiesList.next()){
+	/*for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* ac=gt.rules.activitiesList[i];
 		activitiesListBox->insertItem(ac->getDescription(gt.rules));
 		this->activitiesList.append(ac->id);
+	}*/
+	for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* ac=gt.rules.activitiesList[i];
+		if(filterOk(ac)){
+			activitiesListBox->insertItem(ac->getDescription(gt.rules));
+			this->activitiesList.append(ac->id);
+		}
 	}
 }
 
@@ -56,15 +163,15 @@ void AddConstraintMinNDaysBetweenActivitiesForm::addConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 | weight>100){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
@@ -76,7 +183,7 @@ void AddConstraintMinNDaysBetweenActivitiesForm::addConstraint()
 			QObject::tr("Only one selected activity"));
 		return;
 	}
-	if(this->selectedActivitiesList.count()>(uint)(MAX_CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES)){
+	if(this->selectedActivitiesList.size()>MAX_CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Please report error to the author\nMAX_CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES must be increased (you have too many activities)"));
 		return;
@@ -84,11 +191,14 @@ void AddConstraintMinNDaysBetweenActivitiesForm::addConstraint()
 	
 	int ids[MAX_CONSTRAINT_MIN_N_DAYS_BETWEEN_ACTIVITIES];
 	int i;
-	QValueList<int>::iterator it;
+	QList<int>::iterator it;
 	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++)
 		ids[i]=*it;
 	
-	ctr=new ConstraintMinNDaysBetweenActivities(weight, compulsory, this->selectedActivitiesList.count(), ids, minDaysSpinBox->value());
+	ctr=new ConstraintMinNDaysBetweenActivities(weight, consecutiveIfSameDayCheckBox->isChecked(),/*compulsory,*/ this->selectedActivitiesList.count(), ids, minDaysSpinBox->value());
+
+	//QMessageBox::information(this, QObject::tr("FET information"), ctr->getDetailedDescription(gt.rules));
+
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	
 	if(tmp2){
@@ -99,7 +209,7 @@ void AddConstraintMinNDaysBetweenActivitiesForm::addConstraint()
 	}
 	else{
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Constraint NOT added - please report error"));
+			QObject::tr("Constraint NOT added - it must be a duplicate"));
 		delete ctr;
 	}
 }
@@ -109,7 +219,7 @@ void AddConstraintMinNDaysBetweenActivitiesForm::addActivity()
 	if(activitiesListBox->currentItem()<0)
 		return;
 	int tmp=activitiesListBox->currentItem();
-	int _id=*(this->activitiesList.at(tmp));
+	int _id=this->activitiesList.at(tmp);
 	
 	QString actName=activitiesListBox->currentText();
 	assert(actName!="");
@@ -130,9 +240,13 @@ void AddConstraintMinNDaysBetweenActivitiesForm::removeActivity()
 	if(selectedActivitiesListBox->currentItem()<0 || selectedActivitiesListBox->count()<=0)
 		return;		
 	int tmp=selectedActivitiesListBox->currentItem();
-	int _id=*(this->selectedActivitiesList.at(tmp));
 	
 	selectedActivitiesListBox->removeItem(selectedActivitiesListBox->currentItem());
-	int tmp2=this->selectedActivitiesList.remove(_id);
-	assert(tmp2==1);
+	this->selectedActivitiesList.removeAt(tmp);
+}
+
+void AddConstraintMinNDaysBetweenActivitiesForm::clear()
+{
+	selectedActivitiesListBox->clear();
+	selectedActivitiesList.clear();
 }
