@@ -19,21 +19,22 @@
 #define ADDCONSTRAINTMINNDAYSBETWEENACTIVITIESFORM_H
 
 #include "addconstraintminndaysbetweenactivitiesform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
+
+#include <QList>
 
 class AddConstraintMinNDaysBetweenActivitiesForm : public AddConstraintMinNDaysBetweenActivitiesForm_template  {
 public:
@@ -46,12 +47,17 @@ public:
 	void removeActivity();
 
 	void addConstraint();
+
+	bool filterOk(Activity* a);
+	void filterChanged();	
+	
+	void clear();
 	
 private:
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of selected activities
-	QValueList<int> selectedActivitiesList;
+	QList<int> selectedActivitiesList;
 };
 
 #endif
