@@ -21,10 +21,19 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 AddConstraintRoomNotAvailableForm::AddConstraintRoomNotAvailableForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	updateRoomsComboBox();
 
 	startHourComboBox->clear();
@@ -47,8 +56,10 @@ AddConstraintRoomNotAvailableForm::~AddConstraintRoomNotAvailableForm()
 void AddConstraintRoomNotAvailableForm::updateRoomsComboBox()
 {
 	roomsComboBox->clear();
-	for(Room* room=gt.rules.roomsList.first(); room; room=gt.rules.roomsList.next())
+	for(int i=0; i<gt.rules.roomsList.size(); i++){
+		Room* room=gt.rules.roomsList[i];
 		roomsComboBox->insertItem(room->getDescription());
+	}
 }
 
 void AddConstraintRoomNotAvailableForm::addConstraint()
@@ -58,15 +69,15 @@ void AddConstraintRoomNotAvailableForm::addConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid weight"));
 		return;
 	}
 
-	bool compulsory=false;
+/*	bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	int i=roomsComboBox->currentItem();
 	if(i<0 || roomsComboBox->count()<=0){
@@ -100,7 +111,7 @@ void AddConstraintRoomNotAvailableForm::addConstraint()
 		return;
 	}
 
-	ctr=new ConstraintRoomNotAvailable(weight, compulsory, room->name, day, startHour, endHour);
+	ctr=new ConstraintRoomNotAvailable(weight/*, compulsory*/, room->name, day, startHour, endHour);
 
 	bool tmp2=gt.rules.addSpaceConstraint(ctr);
 	if(tmp2){
