@@ -19,19 +19,19 @@
 #define ADDCONSTRAINTTEACHERNOTAVAILABLEFORM_H
 
 #include "addconstraintteachernotavailableform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 class AddConstraintTeacherNotAvailableForm : public AddConstraintTeacherNotAvailableForm_template  {
 public:
