@@ -19,8 +19,18 @@
 
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
 AddStudentsGroupForm::AddStudentsGroupForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
 }
 
 AddStudentsGroupForm::~AddStudentsGroupForm()
