@@ -19,8 +19,18 @@
 
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
 AddStudentsYearForm::AddStudentsYearForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
 }
 
 AddStudentsYearForm::~AddStudentsYearForm()
@@ -47,7 +57,12 @@ void AddStudentsYearForm::addStudentsYear()
 		assert(tmp);
 
 		QMessageBox::information(this, QObject::tr("Year insertion dialog"),
-			QObject::tr("Year added"));
+			QObject::tr("Year added. You might want to divide it into sections - this is done in the years "
+			"dialog - button 'Divide year ...', or by manually adding groups and subgroups in the groups or subgroups menus\n\n"
+			" Important note: if you plan to use option 'divide', please try to use it only once for each year at the beginning, because"
+			" a second use of option 'divide' for the same year will remove all activities and constraints referring to old groups and subgroups"
+			" from this year."
+			));
 	}
 
 	nameLineEdit->selectAll();
