@@ -17,40 +17,55 @@
 
 #include "alltimeconstraintsform.h"
 
-#include "modifyconstraint2activitiesconsecutiveform.h"
-#include "modifyconstraint2activitiesorderedform.h"
-#include "modifyconstraint2activitiesgroupedform.h"
+#include "modifyconstraintbreakform.h"
+#include "modifyconstraintbasiccompulsorytimeform.h"
+
 #include "modifyconstraintactivitypreferredtimesform.h"
+#include "modifyconstraint2activitiesconsecutiveform.h"
 #include "modifyconstraintactivitiespreferredtimesform.h"
 #include "modifyconstraintactivitiessamestartingtimeform.h"
 #include "modifyconstraintactivitiessamestartinghourform.h"
-#include "modifyconstraintteachernotavailableform.h"
-#include "modifyconstraintbasiccompulsorytimeform.h"
-#include "modifyconstraintstudentssetnotavailableform.h"
-#include "modifyconstraintbreakform.h"
-#include "modifyconstraintteachermaxdaysperweekform.h"
-#include "modifyconstraintteachersmaxhourscontinuouslyform.h"
-#include "modifyconstraintteachersmaxhoursdailyform.h"
-#include "modifyconstraintteacherssubgroupsmaxhoursdailyform.h"
 #include "modifyconstraintactivitypreferredtimeform.h"
-#include "modifyconstraintstudentssetnogapsform.h"
-#include "modifyconstraintstudentsnogapsform.h"
-#include "modifyconstraintteachersnogapsform.h"
-#include "modifyconstraintstudentsearlyform.h"
-#include "modifyconstraintstudentssetintervalmaxdaysperweekform.h"
-#include "modifyconstraintstudentssetnhoursdailyform.h"
-#include "modifyconstraintstudentsnhoursdailyform.h"
-#include "modifyconstraintactivityendsdayform.h"
 #include "modifyconstraintactivitiesnotoverlappingform.h"
 #include "modifyconstraintminndaysbetweenactivitiesform.h"
-#include "modifyconstraintteacherssubjecttagsmaxhourscontinuouslyform.h"
-#include "modifyconstraintteacherssubjecttagmaxhourscontinuouslyform.h"
+#include "modifyconstraintactivityendsstudentsdayform.h"
+
+#include "modifyconstraintteachernotavailableform.h"
+#include "modifyconstraintteachersmaxgapsperweekform.h"
+#include "modifyconstraintteachermaxgapsperweekform.h"
+#include "modifyconstraintteachermaxdaysperweekform.h"
+#include "modifyconstraintteachersmaxhoursdailyform.h"
+#include "modifyconstraintteachermaxhoursdailyform.h"
+#include "modifyconstraintteachersminhoursdailyform.h"
+#include "modifyconstraintteacherminhoursdailyform.h"
+
+#include "modifyconstraintstudentssetnotavailableform.h"
+#include "modifyconstraintstudentssetnogapsform.h"
+#include "modifyconstraintstudentsnogapsform.h"
+#include "modifyconstraintstudentsearlyform.h"
+#include "modifyconstraintstudentssetearlyform.h"
+#include "modifyconstraintstudentssetmaxhoursdailyform.h"
+#include "modifyconstraintstudentsmaxhoursdailyform.h"
+#include "modifyconstraintstudentssetminhoursdailyform.h"
+#include "modifyconstraintstudentsminhoursdailyform.h"
+
+#include <QDesktopWidget>
 
 AllTimeConstraintsForm::AllTimeConstraintsForm()
 {
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
+	setWindowFlags(Qt::Window);
+	
 	constraintsListBox->clear();
-	for(TimeConstraint* ctr=gt.rules.timeConstraintsList.first(); ctr; ctr=gt.rules.timeConstraintsList.next())
-			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
+	for(int i=0; i<gt.rules.timeConstraintsList.size(); i++){
+		TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
+		constraintsListBox->insertItem(ctr->getDescription(gt.rules));
+	}
 }
 
 AllTimeConstraintsForm::~AllTimeConstraintsForm()
@@ -61,8 +76,8 @@ void AllTimeConstraintsForm::constraintChanged(int index)
 {
 	if(index<0)
 		return;
-	assert((uint)(index)<gt.rules.timeConstraintsList.count());
-	TimeConstraint* ctr=gt.rules.timeConstraintsList.at(index);
+	assert(index<gt.rules.timeConstraintsList.size());
+	TimeConstraint* ctr=gt.rules.timeConstraintsList[index];
 	assert(ctr!=NULL);
 	QString s=ctr->getDetailedDescription(gt.rules);
 	currentConstraintTextEdit->setText(s);
@@ -75,7 +90,7 @@ void AllTimeConstraintsForm::removeConstraint()
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Invalid selected constraint"));
 		return;
 	}
-	TimeConstraint* ctr=gt.rules.timeConstraintsList.at(i);
+	TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
 	/*if(ctr->type==CONSTRAINT_BASIC_COMPULSORY_TIME){
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("You cannot erase the basic time constraints"));
 		return;
@@ -110,7 +125,7 @@ void AllTimeConstraintsForm::modifyConstraint()
 		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Invalid selected constraint"));
 		return;
 	}
-	TimeConstraint* ctr=gt.rules.timeConstraintsList.at(i);
+	TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
 	
 	if(ctr->type==CONSTRAINT_BASIC_COMPULSORY_TIME){
 		ModifyConstraintBasicCompulsoryTimeForm* form=
@@ -122,16 +137,6 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraint2ActivitiesConsecutiveForm((Constraint2ActivitiesConsecutive*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_2_ACTIVITIES_ORDERED){
-		ModifyConstraint2ActivitiesOrderedForm* form=
-		 new ModifyConstraint2ActivitiesOrderedForm((Constraint2ActivitiesOrdered*)ctr);
-		form->exec();
-	}
-	else if(ctr->type==CONSTRAINT_2_ACTIVITIES_GROUPED){
-		ModifyConstraint2ActivitiesGroupedForm* form=
-		 new ModifyConstraint2ActivitiesGroupedForm((Constraint2ActivitiesGrouped*)ctr);
-		form->exec();
-	}
 	else if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_TIMES){
 		ModifyConstraintActivityPreferredTimesForm* form=
 		 new ModifyConstraintActivityPreferredTimesForm((ConstraintActivityPreferredTimes*)ctr);
@@ -172,19 +177,34 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintTeacherMaxDaysPerWeekForm((ConstraintTeacherMaxDaysPerWeek*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_HOURS_CONTINUOUSLY){
-		ModifyConstraintTeachersMaxHoursContinuouslyForm* form=
-		 new ModifyConstraintTeachersMaxHoursContinuouslyForm((ConstraintTeachersMaxHoursContinuously*)ctr);
-		form->exec();
-	}
 	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_HOURS_DAILY){
 		ModifyConstraintTeachersMaxHoursDailyForm* form=
 		 new ModifyConstraintTeachersMaxHoursDailyForm((ConstraintTeachersMaxHoursDaily*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_TEACHERS_SUBGROUPS_MAX_HOURS_DAILY){
-		ModifyConstraintTeachersSubgroupsMaxHoursDailyForm* form=
-		 new ModifyConstraintTeachersSubgroupsMaxHoursDailyForm((ConstraintTeachersSubgroupsMaxHoursDaily*)ctr);
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_HOURS_DAILY){
+		ModifyConstraintTeacherMaxHoursDailyForm* form=
+		 new ModifyConstraintTeacherMaxHoursDailyForm((ConstraintTeacherMaxHoursDaily*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHERS_MIN_HOURS_DAILY){
+		ModifyConstraintTeachersMinHoursDailyForm* form=
+		 new ModifyConstraintTeachersMinHoursDailyForm((ConstraintTeachersMinHoursDaily*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHER_MIN_HOURS_DAILY){
+		ModifyConstraintTeacherMinHoursDailyForm* form=
+		 new ModifyConstraintTeacherMinHoursDailyForm((ConstraintTeacherMinHoursDaily*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_GAPS_PER_WEEK){
+		ModifyConstraintTeachersMaxGapsPerWeekForm* form=
+		 new ModifyConstraintTeachersMaxGapsPerWeekForm((ConstraintTeachersMaxGapsPerWeek*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_GAPS_PER_WEEK){
+		ModifyConstraintTeacherMaxGapsPerWeekForm* form=
+		 new ModifyConstraintTeacherMaxGapsPerWeekForm((ConstraintTeacherMaxGapsPerWeek*)ctr);
 		form->exec();
 	}
 	else if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_TIME){
@@ -202,34 +222,34 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintStudentsNoGapsForm((ConstraintStudentsNoGaps*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_TEACHERS_NO_GAPS){
-		ModifyConstraintTeachersNoGapsForm* form=
-		 new ModifyConstraintTeachersNoGapsForm((ConstraintTeachersNoGaps*)ctr);
-		form->exec();
-	}
 	else if(ctr->type==CONSTRAINT_STUDENTS_EARLY){
 		ModifyConstraintStudentsEarlyForm* form=
 		 new ModifyConstraintStudentsEarlyForm((ConstraintStudentsEarly*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_SET_INTERVAL_MAX_DAYS_PER_WEEK){
-		ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm* form=
-		 new ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm((ConstraintStudentsSetIntervalMaxDaysPerWeek*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_EARLY){
+		ModifyConstraintStudentsSetEarlyForm* form=
+		 new ModifyConstraintStudentsSetEarlyForm((ConstraintStudentsSetEarly*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_SET_N_HOURS_DAILY){
-		ModifyConstraintStudentsSetNHoursDailyForm* form=
-		 new ModifyConstraintStudentsSetNHoursDailyForm((ConstraintStudentsSetNHoursDaily*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_HOURS_DAILY){
+		ModifyConstraintStudentsSetMaxHoursDailyForm* form=
+		 new ModifyConstraintStudentsSetMaxHoursDailyForm((ConstraintStudentsSetMaxHoursDaily*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_STUDENTS_N_HOURS_DAILY){
-		ModifyConstraintStudentsNHoursDailyForm* form=
-		 new ModifyConstraintStudentsNHoursDailyForm((ConstraintStudentsNHoursDaily*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_MAX_HOURS_DAILY){
+		ModifyConstraintStudentsMaxHoursDailyForm* form=
+		 new ModifyConstraintStudentsMaxHoursDailyForm((ConstraintStudentsMaxHoursDaily*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_ACTIVITY_ENDS_DAY){
-		ModifyConstraintActivityEndsDayForm* form=
-		 new ModifyConstraintActivityEndsDayForm((ConstraintActivityEndsDay*)ctr);
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MIN_HOURS_DAILY){
+		ModifyConstraintStudentsSetMinHoursDailyForm* form=
+		 new ModifyConstraintStudentsSetMinHoursDailyForm((ConstraintStudentsSetMinHoursDaily*)ctr);
+		form->exec();
+	}
+	else if(ctr->type==CONSTRAINT_STUDENTS_MIN_HOURS_DAILY){
+		ModifyConstraintStudentsMinHoursDailyForm* form=
+		 new ModifyConstraintStudentsMinHoursDailyForm((ConstraintStudentsMinHoursDaily*)ctr);
 		form->exec();
 	}
 	else if(ctr->type==CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING){
@@ -242,14 +262,9 @@ void AllTimeConstraintsForm::modifyConstraint()
 		 new ModifyConstraintMinNDaysBetweenActivitiesForm((ConstraintMinNDaysBetweenActivities*)ctr);
 		form->exec();
 	}
-	else if(ctr->type==CONSTRAINT_TEACHERS_SUBJECT_TAGS_MAX_HOURS_CONTINUOUSLY){
-		ModifyConstraintTeachersSubjectTagsMaxHoursContinuouslyForm* form=
-		 new ModifyConstraintTeachersSubjectTagsMaxHoursContinuouslyForm((ConstraintTeachersSubjectTagsMaxHoursContinuously*)ctr);
-		form->exec();
-	}
-	else if(ctr->type==CONSTRAINT_TEACHERS_SUBJECT_TAG_MAX_HOURS_CONTINUOUSLY){
-		ModifyConstraintTeachersSubjectTagMaxHoursContinuouslyForm* form=
-		 new ModifyConstraintTeachersSubjectTagMaxHoursContinuouslyForm((ConstraintTeachersSubjectTagMaxHoursContinuously*)ctr);
+	else if(ctr->type==CONSTRAINT_ACTIVITY_ENDS_STUDENTS_DAY){
+		ModifyConstraintActivityEndsStudentsDayForm* form=
+		 new ModifyConstraintActivityEndsStudentsDayForm((ConstraintActivityEndsStudentsDay*)ctr);
 		form->exec();
 	}
 	else{
@@ -258,8 +273,10 @@ void AllTimeConstraintsForm::modifyConstraint()
 	}
 
 	constraintsListBox->clear();
-	for(TimeConstraint* ctr=gt.rules.timeConstraintsList.first(); ctr; ctr=gt.rules.timeConstraintsList.next())
-			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
+	for(int i=0; i<gt.rules.timeConstraintsList.size(); i++){
+		TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
+		constraintsListBox->insertItem(ctr->getDescription(gt.rules));
+	}
 
 	constraintsListBox->setCurrentItem(i);
 }
