@@ -19,13 +19,61 @@
 #include "addconstraintactivitypreferredroomform.h"
 #include "modifyconstraintactivitypreferredroomform.h"
 
+#include <QDesktopWidget>
+
 ConstraintActivityPreferredRoomForm::ConstraintActivityPreferredRoomForm()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	roomsComboBox->insertItem("");
-	for(Room* rm=gt.rules.roomsList.first(); rm; rm=gt.rules.roomsList.next())
+	for(int i=0; i<gt.rules.roomsList.size(); i++){
+		Room* rm=gt.rules.roomsList[i];
 		roomsComboBox->insertItem(rm->name);
+	}
+
+/////////////
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	subjectTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* st=gt.rules.subjectTagsList[i];
+		subjectTagsComboBox->insertItem(st->name);
+	}
+	subjectTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
+///////////////
 
-	this->visibleConstraintsList.setAutoDelete(false);
 	this->filterChanged();
 }
 
@@ -35,30 +83,91 @@ ConstraintActivityPreferredRoomForm::~ConstraintActivityPreferredRoomForm()
 
 bool ConstraintActivityPreferredRoomForm::filterOk(SpaceConstraint* ctr)
 {
-	if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_ROOM){
-		ConstraintActivityPreferredRoom* c=(ConstraintActivityPreferredRoom*) ctr;
-		return c->roomName==roomsComboBox->currentText() || roomsComboBox->currentText()=="";
-	}
-	else
+	if(ctr->type!=CONSTRAINT_ACTIVITY_PREFERRED_ROOM)
 		return false;
+		
+	ConstraintActivityPreferredRoom* c=(ConstraintActivityPreferredRoom*) ctr;
+	
+	QString tn=teachersComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=subjectTagsComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+		
+	bool found=true;
+	
+	int id=c->activityId;
+	Activity* act=NULL;
+	foreach(Activity* a, gt.rules.activitiesList)
+		if(a->id==id)
+			act=a;
+
+	found=true;		
+		
+	if(act!=NULL){
+		//teacher
+		if(tn!=""){
+			bool ok2=false;
+			for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+				if(*it == tn){
+					ok2=true;
+					break;
+				}
+			if(!ok2)
+				found=false;
+		}
+
+		//subject
+		if(sbn!="" && sbn!=act->subjectName)
+			found=false;
+	
+		//subject tag
+		if(sbtn!="" && sbtn!=act->subjectTagName)
+			found=false;
+	
+		//students
+		if(stn!=""){
+			bool ok2=false;
+			for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+				if(*it == stn){
+					ok2=true;
+					break;
+			}
+			if(!ok2)
+				found=false;
+		}
+	}
+	
+	if(!found)
+		return false;
+	
+	return c->roomName==roomsComboBox->currentText() || roomsComboBox->currentText()=="";
 }
 
 void ConstraintActivityPreferredRoomForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListBox->clear();
-	for(SpaceConstraint* ctr=gt.rules.spaceConstraintsList.first(); ctr; ctr=gt.rules.spaceConstraintsList.next())
+	for(int i=0; i<gt.rules.spaceConstraintsList.size(); i++){
+		SpaceConstraint* ctr=gt.rules.spaceConstraintsList[i];
 		if(filterOk(ctr)){
 			visibleConstraintsList.append(ctr);
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
+	}
+
+	if(visibleConstraintsList.count()>0)
+		constraintChanged(0);
+	else
+		constraintChanged(-1);
 }
 
 void ConstraintActivityPreferredRoomForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText(tr("Invalid constraint"));
 		return;
-	assert((uint)(index)<this->visibleConstraintsList.count());
+	}
+	assert(index<this->visibleConstraintsList.size());
 	SpaceConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
 	currentConstraintTextEdit->setText(ctr->getDetailedDescription(gt.rules));
@@ -66,8 +175,8 @@ void ConstraintActivityPreferredRoomForm::constraintChanged(int index)
 
 void ConstraintActivityPreferredRoomForm::addConstraint()
 {
-	AddConstraintActivityPreferredRoomForm *addConstraintActivityPreferredRoomForm=new AddConstraintActivityPreferredRoomForm();
-	addConstraintActivityPreferredRoomForm->exec();
+	AddConstraintActivityPreferredRoomForm *form=new AddConstraintActivityPreferredRoomForm();
+	form->exec();
 
 	filterChanged();
 	
@@ -83,9 +192,8 @@ void ConstraintActivityPreferredRoomForm::modifyConstraint()
 	}
 	SpaceConstraint* ctr=this->visibleConstraintsList.at(i);
 
-	ModifyConstraintActivityPreferredRoomForm *modifyConstraintActivityPreferredRoomForm
-	 = new ModifyConstraintActivityPreferredRoomForm((ConstraintActivityPreferredRoom*)ctr);
-	modifyConstraintActivityPreferredRoomForm->exec();
+	ModifyConstraintActivityPreferredRoomForm *form = new ModifyConstraintActivityPreferredRoomForm((ConstraintActivityPreferredRoom*)ctr);
+	form->exec();
 
 	filterChanged();
 	constraintsListBox->setCurrentItem(i);
