@@ -19,9 +19,55 @@
 #include "addconstraintactivitypreferredtimeform.h"
 #include "modifyconstraintactivitypreferredtimeform.h"
 
+#include <QDesktopWidget>
+
 ConstraintActivityPreferredTimeForm::ConstraintActivityPreferredTimeForm()
 {
-	this->visibleConstraintsList.setAutoDelete(false);
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
+/////////////
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	subjectTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* st=gt.rules.subjectTagsList[i];
+		subjectTagsComboBox->insertItem(st->name);
+	}
+	subjectTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
+///////////////
+
 	this->filterChanged();
 }
 
@@ -31,28 +77,91 @@ ConstraintActivityPreferredTimeForm::~ConstraintActivityPreferredTimeForm()
 
 bool ConstraintActivityPreferredTimeForm::filterOk(TimeConstraint* ctr)
 {
-	if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_TIME)
-		return true;
-	else
+	if(ctr->type!=CONSTRAINT_ACTIVITY_PREFERRED_TIME)
 		return false;
+		
+	ConstraintActivityPreferredTime* c=(ConstraintActivityPreferredTime*) ctr;
+	
+	QString tn=teachersComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=subjectTagsComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+		
+	bool found=true;
+	
+	int id=c->activityId;
+	Activity* act=NULL;
+	foreach(Activity* a, gt.rules.activitiesList)
+		if(a->id==id)
+			act=a;
+
+	found=true;		
+		
+	if(act!=NULL){
+		//teacher
+		if(tn!=""){
+			bool ok2=false;
+			for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+				if(*it == tn){
+					ok2=true;
+					break;
+				}
+			if(!ok2)
+				found=false;
+		}
+
+		//subject
+		if(sbn!="" && sbn!=act->subjectName)
+			found=false;
+	
+		//subject tag
+		if(sbtn!="" && sbtn!=act->subjectTagName)
+			found=false;
+	
+		//students
+		if(stn!=""){
+			bool ok2=false;
+			for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+				if(*it == stn){
+					ok2=true;
+					break;
+			}
+			if(!ok2)
+				found=false;
+		}
+	}
+	
+	if(found)
+		return true;
+
+	return false;
 }
 
 void ConstraintActivityPreferredTimeForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListBox->clear();
-	for(TimeConstraint* ctr=gt.rules.timeConstraintsList.first(); ctr; ctr=gt.rules.timeConstraintsList.next())
+	for(int i=0; i<gt.rules.timeConstraintsList.size(); i++){
+		TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
 		if(filterOk(ctr)){
 			visibleConstraintsList.append(ctr);
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
+	}
+
+	if(visibleConstraintsList.count()>0)
+		constraintChanged(0);
+	else
+		constraintChanged(-1);
 }
 
 void ConstraintActivityPreferredTimeForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText(tr("Invalid constraint"));
 		return;
-	assert((uint)(index)<this->visibleConstraintsList.count());
+	}
+	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
 	currentConstraintTextEdit->setText(ctr->getDetailedDescription(gt.rules));
@@ -60,8 +169,8 @@ void ConstraintActivityPreferredTimeForm::constraintChanged(int index)
 
 void ConstraintActivityPreferredTimeForm::addConstraint()
 {
-	AddConstraintActivityPreferredTimeForm *addConstraintActivityPreferredTimeForm=new AddConstraintActivityPreferredTimeForm();
-	addConstraintActivityPreferredTimeForm->exec();
+	AddConstraintActivityPreferredTimeForm *form=new AddConstraintActivityPreferredTimeForm();
+	form->exec();
 
 	filterChanged();
 	
@@ -77,9 +186,8 @@ void ConstraintActivityPreferredTimeForm::modifyConstraint()
 	}
 	TimeConstraint* ctr=this->visibleConstraintsList.at(i);
 
-	ModifyConstraintActivityPreferredTimeForm *modifyConstraintActivityPreferredTimeForm
-	 = new ModifyConstraintActivityPreferredTimeForm((ConstraintActivityPreferredTime*)ctr);
-	modifyConstraintActivityPreferredTimeForm->exec();
+	ModifyConstraintActivityPreferredTimeForm *form = new ModifyConstraintActivityPreferredTimeForm((ConstraintActivityPreferredTime*)ctr);
+	form->exec();
 
 	filterChanged();
 	constraintsListBox->setCurrentItem(i);
