@@ -10,8 +10,8 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
 
 #include "daysform.h"
@@ -20,7 +20,9 @@
 #include <qlineedit.h>
 #include <qmessagebox.h>
 
-extern GeneticTimetable gt;
+#include <QDesktopWidget>
+
+extern Timetable gt;
 
 QLineEdit* daysNames[14];
 int nDays;
@@ -28,6 +30,13 @@ int nDays;
 DaysForm::DaysForm()
  : DaysForm_template()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	nDays=gt.rules.nDaysPerWeek;
 	daysNames[0]=day1LineEdit;
 	daysNames[1]=day2LineEdit;
@@ -93,10 +102,17 @@ void DaysForm::ok()
 		QObject::tr("Please note that FET will NOT take care\n"
 		"of old constraints using erased days\n"
 		"(only renamed days will be handled correctly)\n"));
+		
+	//remove old names
+	for(int i=nDays; i<gt.rules.nDaysPerWeek; i++)
+		gt.rules.daysOfTheWeek[i]="";
 
 	gt.rules.nDaysPerWeek=nDays;
 	for(int i=0; i<nDays; i++)
 		gt.rules.daysOfTheWeek[i]=daysNames[i]->text();
+		
+	gt.rules.nHoursPerWeek=gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay; //not needed
+	gt.rules.internalStructureComputed=false;
 
 	this->close();
 }
