@@ -23,15 +23,9 @@
 #include <qlabel.h>
 #include <qtabwidget.h>
 
+#include <QDesktopWidget>
+
 #define subTab(i)	subactivitiesTabWidget->page(i)
-#define par(i)		(i==0?parity1CheckBox:			\
-			(i==1?parity2CheckBox:					\
-			(i==2?parity3CheckBox:					\
-			(i==3?parity4CheckBox:					\
-			(i==4?parity5CheckBox:					\
-			(i==5?parity6CheckBox:					\
-			(i==6?parity7CheckBox:					\
-			(parity8CheckBox))))))))
 #define dur(i)		(i==0?duration1SpinBox:			\
 			(i==1?duration2SpinBox:					\
 			(i==2?duration3SpinBox:					\
@@ -39,7 +33,9 @@
 			(i==4?duration5SpinBox:					\
 			(i==5?duration6SpinBox:					\
 			(i==6?duration7SpinBox:					\
-			(duration8SpinBox))))))))
+			(i==7?duration8SpinBox:					\
+			(i==8?duration9SpinBox:					\
+			(duration10SpinBox))))))))))
 #define activ(i)		(i==0?active1CheckBox:			\
 			(i==1?active2CheckBox:					\
 			(i==2?active3CheckBox:					\
@@ -47,15 +43,26 @@
 			(i==4?active5CheckBox:					\
 			(i==5?active6CheckBox:					\
 			(i==6?active7CheckBox:					\
-			(active8CheckBox))))))))
+			(i==7?active8CheckBox:					\
+			(i==8?active9CheckBox:					\
+			(active10CheckBox))))))))))
 
 ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_id=id;
 	this->_activityGroupId=activityGroupId;
-	for(Activity* act=gt.rules.activitiesList.first(); act; act=gt.rules.activitiesList.next())
+	for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* act=gt.rules.activitiesList[i];
 		if(act->activityGroupId==this->_activityGroupId && act->id==this->_id)
 			this->_activity=act;
+	}
 			
 	this->_teachers=this->_activity->teachersNames;
 	this->_subject = this->_activity->subjectName;
@@ -66,24 +73,26 @@ ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 	
 	if(this->_activityGroupId!=0){
 		nSplit=0;
-		for(Activity* act=gt.rules.activitiesList.first(); act; act=gt.rules.activitiesList.next())
+		for(int i=0; i<gt.rules.activitiesList.size(); i++){
+			Activity* act=gt.rules.activitiesList[i];
 			if(act->activityGroupId==this->_activityGroupId){
-				if(nSplit>=8){
+				if(nSplit>=10){
 					assert(0);
 				}
 				else{
 					if(this->_id==act->id)
 						subactivitiesTabWidget->setCurrentPage(nSplit);
-					par(nSplit)->setChecked(act->parity==PARITY_BIWEEKLY);
+					//par(nSplit)->setChecked(act->parity==PARITY_FORTNIGHTLY);
 					dur(nSplit)->setValue(act->duration);
 					activ(nSplit)->setChecked(act->active);
 					nSplit++;
 				}
 			}
+		}
 	}
 	else{
 		nSplit=1;
-		par(0)->setChecked(this->_activity->parity==PARITY_BIWEEKLY);
+		//par(0)->setChecked(this->_activity->parity==PARITY_FORTNIGHTLY);
 		dur(0)->setValue(this->_activity->duration);
 		activ(0)->setChecked(this->_activity->active);
 	}
@@ -92,12 +101,20 @@ ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 	splitSpinBox->setMaxValue(nSplit);	
 	splitSpinBox->setValue(nSplit);	
 	
+	if(nSplit==1)
+		currentActivityTextLabel->setText(tr("Current activity"));
+	else
+		currentActivityTextLabel->setText(tr("Current activities"));
+	
+	if(this->_activity->computeNTotalStudents==false)
+		nStudentsSpinBox->setValue(this->_activity->nTotalStudents);
+	
 	updateStudentsListBox();
 	updateTeachersListBox();
 	updateSubjectsComboBox();
 	updateSubjectTagsComboBox();
 
-	for(int i=0; i<8; i++)
+	for(int i=0; i<10; i++)
 		if(i<nSplit)
 			subTab(i)->setEnabled(true);
 		else
@@ -111,8 +128,10 @@ ModifyActivityForm::~ModifyActivityForm()
 void ModifyActivityForm::updateTeachersListBox()
 {
 	allTeachersListBox->clear();
-	for(Teacher* tch=gt.rules.teachersList.first(); tch; tch=gt.rules.teachersList.next())
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
 		allTeachersListBox->insertItem(tch->name);
+	}
 		
 	selectedTeachersListBox->clear();
 	for(QStringList::Iterator it=this->_teachers.begin(); it!=this->_teachers.end(); it++)
@@ -125,7 +144,8 @@ void ModifyActivityForm::updateSubjectsComboBox()
 {
 	int i=0, j=-1;
 	subjectsComboBox->clear();
-	for(Subject* sbj=gt.rules.subjectsList.first(); sbj; sbj=gt.rules.subjectsList.next(), i++){
+	for(int k=0; k<gt.rules.subjectsList.size(); k++, i++){
+		Subject* sbj=gt.rules.subjectsList[k];
 		subjectsComboBox->insertItem(sbj->name);
 		if(sbj->name==this->_subject)
 			j=i;
@@ -144,7 +164,8 @@ void ModifyActivityForm::updateSubjectTagsComboBox()
 	if(this->_subjectTag=="")
 		j=i;
 	i++;
-	for(SubjectTag* sbt=gt.rules.subjectTagsList.first(); sbt; sbt=gt.rules.subjectTagsList.next(), i++){
+	for(int k=0; k<gt.rules.subjectTagsList.size(); k++, i++){
+		SubjectTag* sbt=gt.rules.subjectTagsList[k];
 		subjectTagsComboBox->insertItem(sbt->name);
 		if(sbt->name==this->_subjectTag)
 			j=i;
@@ -158,12 +179,16 @@ void ModifyActivityForm::updateSubjectTagsComboBox()
 void ModifyActivityForm::updateStudentsListBox()
 {
 	allStudentsListBox->clear();
-	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next()){
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
 		allStudentsListBox->insertItem(sty->name);
-		for(StudentsGroup* stg=sty->groupsList.first(); stg; stg=sty->groupsList.next()){
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
 			allStudentsListBox->insertItem(stg->name);
-			for(StudentsSubgroup* sts=stg->subgroupsList.first(); sts; sts=stg->subgroupsList.next())
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
 				allStudentsListBox->insertItem(sts->name);
+			}
 		}
 	}
 	
@@ -243,62 +268,85 @@ void ModifyActivityForm::subjectTagChanged(const QString& dummy)
 void ModifyActivityForm::activityChanged()
 {
 	QString s;
-	s+=QObject::tr("Current activity:");
-	s+="\n";
+	//s+=tr("Current activity:");
+	//s+="\n";
 	
-	for(uint i=0; i<selectedTeachersListBox->count(); i++){
-		s+=QObject::tr(QString("Teacher=%1").arg(selectedTeachersListBox->text(i)));
-		s+="\n";
+	if(selectedTeachersListBox->count()==0){
+		if(splitSpinBox->value()==1)
+			s+=tr("No teachers for this activity\n");
+		else
+			s+=tr("No teachers for these activities\n");
 	}
+	else
+		for(uint i=0; i<selectedTeachersListBox->count(); i++){
+			s+=tr("Teacher=%1").arg(selectedTeachersListBox->text(i));
+			s+="\n";
+		}
 
-	s+=QObject::tr(QString("Subject=%1").arg(subjectsComboBox->currentText()));
+	s+=tr("Subject=%1").arg(subjectsComboBox->currentText());
 	s+="\n";
 	if(subjectTagsComboBox->currentText()!=""){
-		s+=QObject::tr(QString("Subject tag=%1").arg(subjectTagsComboBox->currentText()));
+		s+=tr("Subject tag=%1").arg(subjectTagsComboBox->currentText());
 		s+="\n";
 	}
-	for(uint i=0; i<selectedStudentsListBox->count(); i++){
-		s+=QObject::tr(QString("Students=%1").arg(selectedStudentsListBox->text(i)));
-		s+="\n";
+	if(selectedStudentsListBox->count()==0){
+		if(splitSpinBox->value()==1)
+			s+=tr("No students for this activity\n");
+		else
+			s+=tr("No students for these activities\n");
+	}
+	else
+		for(uint i=0; i<selectedStudentsListBox->count(); i++){
+			s+=tr("Students=%1").arg(selectedStudentsListBox->text(i));
+			s+="\n";
+		}
+	
+	if(nStudentsSpinBox->value()==-1){
+		s+=tr("Number of students: computed from corresponding students sets");
+		s+="\n";	
+	}
+	else{
+		s+=tr("Number of students=%1").arg(nStudentsSpinBox->value());
+		s+="\n";	
 	}
 
 	if(splitSpinBox->value()==1){
-		s+=QObject::tr(QString("Duration=%1").arg(dur(0)->value()));
+		s+=tr("Duration=%1").arg(dur(0)->value());
 		s+="\n";
-		if(par(0)->isChecked()){
-			s+=QObject::tr("Bi-weekly activity");
+		/*if(par(0)->isChecked()){
+			s+=tr("Fortnightly activity");
 			s+="\n";
-		}
+		}*/
 		
 		if(activ(0)->isChecked()){
-			s+=QObject::tr("Active activity");
+			s+=tr("Active activity");
 			s+="\n";
 		}
 		else{
-			s+=QObject::tr("Non-active activity");
+			s+=tr("Non-active activity");
 			s+="\n";
 		}
 	}
 	else{
-		s+=QObject::tr(QString("This activity will be split into %1 lessons per week").arg(splitSpinBox->value()));
+		s+=tr("This larger activity is split into %1 smaller activities per week").arg(splitSpinBox->value());
 		s+="\n";
 		s+="\n";
 
 		for(int i=0; i<splitSpinBox->value(); i++){
-			s+=QObject::tr("Componenent %1:").arg(i+1);
+			s+=tr("Componenent %1:").arg(i+1);
 			s+="\n";
-			s+=QObject::tr(QString("Duration=%1").arg(dur(i)->value()));
+			s+=tr("Duration=%1").arg(dur(i)->value());
 			s+="\n";
-			if(par(i)->isChecked()){
-				s+=QObject::tr("Bi-weekly activity");
+			/*if(par(i)->isChecked()){
+				s+=tr("Fortnightly activity");
 				s+="\n";
-			}
+			}*/
 			if(activ(i)->isChecked()){
-				s+=QObject::tr("Active activity");
+				s+=tr("Active activity");
 				s+="\n";
 			}
 			else{
-				s+=QObject::tr("Non-active activity");
+				s+=tr("Non-active activity");
 				s+="\n";
 			}
 			s+="\n";
@@ -318,13 +366,16 @@ void ModifyActivityForm::ok()
 	//teachers
 	QStringList teachers_names;
 	if(selectedTeachersListBox->count()<=0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid teacher(s)"));
-		return;
+		int t=QMessageBox::question(this, tr("FET question"),
+		 tr("Do you really want to have the activity with no teacher(s)?"),
+		 QMessageBox::Yes, QMessageBox::Cancel);
+
+		if(t==QMessageBox::Cancel)
+			return;
 	}
 	else if(selectedTeachersListBox->count()>(uint)(MAX_TEACHERS_PER_ACTIVITY)){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Too many teachers for an activity. The current maximum is %1.\n"
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Too many teachers for an activity. The current maximum is %1.\n"
 			"If you really need more teachers per activity, please talk to the author").
 			arg(MAX_TEACHERS_PER_ACTIVITY));
 		return;
@@ -340,8 +391,8 @@ void ModifyActivityForm::ok()
 	QString subject_name=subjectsComboBox->currentText();
 	int subject_index=gt.rules.searchSubject(subject_name);
 	if(subject_index<0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid subject"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid subject"));
 		return;
 	}
 
@@ -349,17 +400,20 @@ void ModifyActivityForm::ok()
 	QString subject_tag_name=subjectTagsComboBox->currentText();
 	int subject_tag_index=gt.rules.searchSubjectTag(subject_tag_name);
 	if(subject_tag_index<0 && subject_tag_name!=""){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid subject tag"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid subject tag"));
 		return;
 	}
 
 	//students
 	QStringList students_names;
 	if(selectedStudentsListBox->count()<=0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid students set(s)"));
-		return;
+		int t=QMessageBox::question(this, tr("FET question"),
+		 tr("Do you really want to have the activity with no student set(s)?"),
+		 QMessageBox::Yes, QMessageBox::Cancel);
+
+		if(t==QMessageBox::Cancel)
+			return;
 	}
 	else{
 		for(uint i=0; i<selectedStudentsListBox->count(); i++){
@@ -375,24 +429,32 @@ void ModifyActivityForm::ok()
 	}
 
 	int totalduration;
-	int durations[8];
-	int parities[8];
-	bool active[8];
+	int durations[10];
+	//int parities[8];
+	bool active[10];
 	int nsplit=splitSpinBox->value();
 
 	totalduration=0;
 	for(int i=0; i<nsplit; i++){
 		durations[i]=dur(i)->value();
-		parities[i]=PARITY_WEEKLY;
-		if(par(i)->isChecked())
-			parities[i]=PARITY_BIWEEKLY;
+		//parities[i]=PARITY_WEEKLY;
+		//if(par(i)->isChecked())
+		//	parities[i]=PARITY_FORTNIGHTLY;
 		active[i]=activ(i)->isChecked();
 
 		totalduration+=durations[i];
 	}
 
-	gt.rules.modifyActivity(this->_id, this->_activityGroupId, teachers_names, subject_name,
-	 subject_tag_name,students_names, total_number_of_students, nsplit, totalduration, durations, parities, active);
+	if(nStudentsSpinBox->value()==-1){
+		gt.rules.modifyActivity(this->_id, this->_activityGroupId, teachers_names, subject_name,
+		 subject_tag_name,students_names, nsplit, totalduration, durations, /*parities,*/ active,
+		 (nStudentsSpinBox->value()==-1), total_number_of_students);
+	}
+	else{
+		gt.rules.modifyActivity(this->_id, this->_activityGroupId, teachers_names, subject_name,
+		 subject_tag_name,students_names, nsplit, totalduration, durations, /*parities,*/ active,
+		 (nStudentsSpinBox->value()==-1), nStudentsSpinBox->value());
+	}
 	
 	this->close();
 }
@@ -409,7 +471,8 @@ void ModifyActivityForm::clearStudents()
 	activityChanged();
 }
 
-#undef prefDay
-#undef prefHour
+//#undef prefDay
+//#undef prefHour
 #undef subTab
 #undef activ
+#undef dur
