@@ -20,24 +20,26 @@
 
 #include "modifyactivityform_template.h"
 
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
 
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlistbox.h>
+#include <q3textedit.h>
+#include <q3listbox.h>
 
 
 class ModifyActivityForm : public ModifyActivityForm_template  {
+	Q_OBJECT
+
 public:
 	int _id;
 	int _activityGroupId;
@@ -64,7 +66,7 @@ public:
 
 	void subjectChanged(const QString& dummy);
 	void subjectTagChanged(const QString& dummy);
-	void parityChanged();
+	//void parityChanged();
 	void durationChanged();
 	void activityChanged();
 	
