@@ -22,14 +22,59 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
 #define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
 
 ModifyConstraintActivityPreferredTimeForm::ModifyConstraintActivityPreferredTimeForm(ConstraintActivityPreferredTime* ctr)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_ctr=ctr;
 	
-	compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weight));
+	//compulsoryCheckBox->setChecked(ctr->compulsory);
+	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	subjectTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* st=gt.rules.subjectTagsList[i];
+		subjectTagsComboBox->insertItem(st->name);
+	}
+	subjectTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
 	
 	updatePeriodGroupBox();
 	updateActivitiesComboBox();
@@ -44,15 +89,70 @@ ModifyConstraintActivityPreferredTimeForm::~ModifyConstraintActivityPreferredTim
 {
 }
 
+bool ModifyConstraintActivityPreferredTimeForm::filterOk(Activity* act)
+{
+	QString tn=teachersComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=subjectTagsComboBox->currentText();
+	int ok=true;
+
+	//teacher
+	if(tn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+			if(*it == tn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+
+	//subject
+	if(sbn!="" && sbn!=act->subjectName)
+		ok=false;
+		
+	//subject tag
+	if(sbtn!="" && sbtn!=act->subjectTagName)
+		ok=false;
+		
+	//students
+	if(stn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+			if(*it == stn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+	
+	return ok;
+}
+
+void ModifyConstraintActivityPreferredTimeForm::filterChanged()
+{
+	this->updateActivitiesComboBox();
+}
+
 void ModifyConstraintActivityPreferredTimeForm::updateActivitiesComboBox(){
 	activitiesComboBox->clear();
+	activitiesList.clear();
 	int i=0, j=-1;
-	for(Activity* act=gt.rules.activitiesList.first(); act; act=gt.rules.activitiesList.next(), i++){
-		activitiesComboBox->insertItem(act->getDescription(gt.rules));
-		if(act->id==this->_ctr->activityId)
-			j=i;
+	for(int k=0; k<gt.rules.activitiesList.size(); k++){
+		Activity* act=gt.rules.activitiesList[k];
+		if(filterOk(act)){
+			activitiesComboBox->insertItem(act->getDescription(gt.rules));
+			this->activitiesList.append(act->id);
+			if(act->id==this->_ctr->activityId)
+				j=i;
+				
+			i++;
+		}
 	}
-	assert(j>=0);
+	//assert(j>=0); only first time
 	activitiesComboBox->setCurrentItem(j);
 
 	constraintChanged();
@@ -61,7 +161,7 @@ void ModifyConstraintActivityPreferredTimeForm::updateActivitiesComboBox(){
 void ModifyConstraintActivityPreferredTimeForm::updatePeriodGroupBox(){
 	startHourComboBox->clear();
 	startHourComboBox->insertItem(QObject::tr("Any"));
-	for(int i=0; i<=gt.rules.nHoursPerDay; i++)
+	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
 
 	dayComboBox->clear();
@@ -79,26 +179,28 @@ void ModifyConstraintActivityPreferredTimeForm::constraintChanged()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr("Weight=%1").arg(weight);
+	s+=QObject::tr("Weight (percentage)=%1\%").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
 		compulsory=true;
 	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
-	s+="\n";
+	s+="\n";*/
 
 	s+=QObject::tr("Activity preferred time");
 	s+="\n";
 	
 	int id;
 	int tmp2=activitiesComboBox->currentItem();
-	if(tmp2<0 || (uint)(tmp2)>=gt.rules.activitiesList.count()){
+	assert(tmp2<gt.rules.activitiesList.size());
+	assert(tmp2<activitiesList.size());
+	if(tmp2<0){
 		s+=QObject::tr("Invalid activity");
 		s+="\n";
 	}
 	else{
-		id=gt.rules.activitiesList.at(tmp2)->id;
+		id=activitiesList.at(tmp2);
 		s+=QObject::tr("Activity id=%1").arg(id);
 		s+="\n";
 	}
@@ -131,15 +233,15 @@ void ModifyConstraintActivityPreferredTimeForm::ok()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	int day=dayComboBox->currentItem();
 	if(day<0 || day>gt.rules.nDaysPerWeek){
@@ -161,15 +263,29 @@ void ModifyConstraintActivityPreferredTimeForm::ok()
 	}
 	
 	int tmp2=activitiesComboBox->currentItem();
-	if(tmp2<0 || (uint)(tmp2)>=gt.rules.activitiesList.count()){
+	assert(tmp2<gt.rules.activitiesList.size());
+	assert(tmp2<activitiesList.size());
+	if(tmp2<0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid activity"));
 		return;
 	}
-	int id=gt.rules.activitiesList.at(tmp2)->id;
+	int id=activitiesList.at(tmp2);
+	
+	foreach(TimeConstraint* tc, gt.rules.timeConstraintsList)
+		if(tc->type==CONSTRAINT_ACTIVITY_PREFERRED_TIME){
+			ConstraintActivityPreferredTime* c=(ConstraintActivityPreferredTime*) tc;
+			if(c->activityId==id && c!=this->_ctr){
+				QMessageBox::warning(this, QObject::tr("FET information"),
+				 QObject::tr("This activity id has other constraint of this type attached\n"
+				 "Please remove the other constraints of type activity preferred time\n"
+				 "referring to this activity before proceeding"));
+				return;
+			}
+		}
 
-	this->_ctr->weight=weight;
-	this->_ctr->compulsory=compulsory;
+	this->_ctr->weightPercentage=weight;
+	//this->_ctr->compulsory=compulsory;
 	this->_ctr->day=day-1;
 	this->_ctr->hour=startHour-1;
 	this->_ctr->activityId=id;
