@@ -22,14 +22,23 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
 #define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
 
 ModifyConstraintStudentsSetNoGapsForm::ModifyConstraintStudentsSetNoGapsForm(ConstraintStudentsSetNoGaps* ctr)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_ctr=ctr;
 	
-	compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weight));
+	//compulsoryCheckBox->setChecked(ctr->compulsory);
+	weightLineEdit->setText(QString::number(ctr->weightPercentage));
 	
 	updateStudentsComboBox();
 
@@ -43,17 +52,20 @@ ModifyConstraintStudentsSetNoGapsForm::~ModifyConstraintStudentsSetNoGapsForm()
 void ModifyConstraintStudentsSetNoGapsForm::updateStudentsComboBox(){
 	studentsComboBox->clear();
 	int i=0, j=-1;
-	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next()){
+	for(int m=0; m<gt.rules.yearsList.size(); m++){
+		StudentsYear* sty=gt.rules.yearsList[m];
 		studentsComboBox->insertItem(sty->name);
 		if(sty->name==this->_ctr->students)
 			j=i;
 		i++;
-		for(StudentsGroup* stg=sty->groupsList.first(); stg; stg=sty->groupsList.next()){
+		for(int n=0; n<sty->groupsList.size(); n++){
+			StudentsGroup* stg=sty->groupsList[n];
 			studentsComboBox->insertItem(stg->name);
 			if(stg->name==this->_ctr->students)
 				j=i;
 			i++;
-			for(StudentsSubgroup* sts=stg->subgroupsList.first(); sts; sts=stg->subgroupsList.next()){
+			for(int p=0; p<stg->subgroupsList.size(); p++){
+				StudentsSubgroup* sts=stg->subgroupsList[p];
 				studentsComboBox->insertItem(sts->name);
 				if(sts->name==this->_ctr->students)
 					j=i;
@@ -76,14 +88,14 @@ void ModifyConstraintStudentsSetNoGapsForm::constraintChanged()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr("Weight=%1").arg(weight);
+	s+=QObject::tr("Weight (percentage)=%1\%").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
 		compulsory=true;
 	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
-	s+="\n";
+	s+="\n";*/
 
 	s+=QObject::tr("Students set no gaps");
 	s+="\n";
@@ -98,15 +110,20 @@ void ModifyConstraintStudentsSetNoGapsForm::ok()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
+		return;
+	}
+	if(weight!=100.0){
+		QMessageBox::warning(this, QObject::tr("FET information"),
+			QObject::tr("Invalid weight (percentage) - it must be 100%"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
@@ -116,8 +133,8 @@ void ModifyConstraintStudentsSetNoGapsForm::ok()
 		return;
 	}
 
-	this->_ctr->weight=weight;
-	this->_ctr->compulsory=compulsory;
+	this->_ctr->weightPercentage=weight;
+	//this->_ctr->compulsory=compulsory;
 	this->_ctr->students=students_name;
 
 	gt.rules.internalStructureComputed=false;
