@@ -21,14 +21,24 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 ModifyConstraintSubjectPreferredRoomsForm::ModifyConstraintSubjectPreferredRoomsForm(ConstraintSubjectPreferredRooms* ctr)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	updateRoomsListBox();
 	
 	int i=0, j=-1;
-	for(Subject* sb=gt.rules.subjectsList.first(); sb; sb=gt.rules.subjectsList.next()){
+	for(int k=0; k<gt.rules.subjectsList.size(); k++){
+		Subject* sb=gt.rules.subjectsList[k];
 		subjectsComboBox->insertItem(sb->name);
 		if(ctr->subjectName==sb->name){
 			assert(j==-1);
@@ -41,8 +51,8 @@ ModifyConstraintSubjectPreferredRoomsForm::ModifyConstraintSubjectPreferredRooms
 	
 	this->_ctr=ctr;
 	
-	weightLineEdit->setText(QString::number(ctr->weight));
-	compulsoryCheckBox->setChecked(ctr->compulsory);
+	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	//compulsoryCheckBox->setChecked(ctr->compulsory);
 	
 	for(QStringList::Iterator it=ctr->roomsNames.begin(); it!=ctr->roomsNames.end(); it++)
 		selectedRoomsListBox->insertItem(*it);
@@ -57,8 +67,10 @@ void ModifyConstraintSubjectPreferredRoomsForm::updateRoomsListBox()
 	roomsListBox->clear();
 	selectedRoomsListBox->clear();
 
-	for(Room* rm=gt.rules.roomsList.first(); rm; rm=gt.rules.roomsList.next())
+	for(int i=0; i<gt.rules.roomsList.size(); i++){
+		Room* rm=gt.rules.roomsList[i];
 		roomsListBox->insertItem(rm->name);
+	}
 }
 
 void ModifyConstraintSubjectPreferredRoomsForm::ok()
@@ -66,15 +78,15 @@ void ModifyConstraintSubjectPreferredRoomsForm::ok()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid weight"));
 		return;
 	}
 
-	bool compulsory=false;
+/*	bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	if(selectedRoomsListBox->count()==0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
@@ -83,7 +95,7 @@ void ModifyConstraintSubjectPreferredRoomsForm::ok()
 	}
 	if(selectedRoomsListBox->count()==1){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Only one selected room"));
+			QObject::tr("Only one selected room - please use constraint subject preferred room if you want a single room"));
 		return;
 	}
 	if(selectedRoomsListBox->count()>(uint)(MAX_CONSTRAINT_SUBJECT_PREFERRED_ROOMS)){
@@ -103,8 +115,8 @@ void ModifyConstraintSubjectPreferredRoomsForm::ok()
 	for(uint i=0; i<selectedRoomsListBox->count(); i++)
 		roomsList.append(selectedRoomsListBox->text(i));
 	
-	this->_ctr->weight=weight;
-	this->_ctr->compulsory=compulsory;
+	this->_ctr->weightPercentage=weight;
+//	this->_ctr->compulsory=compulsory;
 	this->_ctr->subjectName=subject;
 	this->_ctr->roomsNames=roomsList;
 	
