@@ -19,8 +19,19 @@
 
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
 ModifyStudentsGroupForm::ModifyStudentsGroupForm(const QString& yearName, const QString& initialGroupName, int initialNumberOfStudents)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_yearName=yearName;
 	this->_initialGroupName=initialGroupName;
 	this->_initialNumberOfStudents=initialNumberOfStudents;
@@ -50,7 +61,11 @@ void ModifyStudentsGroupForm::ok()
 	QString groupName=nameLineEdit->text();
 	
 	if(this->_initialGroupName!=groupName && gt.rules.searchStudentsSet(groupName)!=NULL){
-		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Name existing - please choose another"));
+		QMessageBox::information(this, QObject::tr("FET information"), 
+		 QObject::tr("Name exists. If you would like to make more years to contain a group (overlapping years),"
+		 " please remove current group (FET will unfortunately remove all related activities and constraints)"
+		 " and add a new group with desired name in current year."
+		 " I know this is a not an elegant procedure, I'll try to fix that in the future."));
 		return;
 	}
 	
