@@ -19,8 +19,19 @@
 
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
 ModifyStudentsSubgroupForm::ModifyStudentsSubgroupForm(const QString& yearName, const QString& groupName, const QString& initialSubgroupName, int initialNumberOfStudents)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_yearName=yearName;
 	this->_groupName=groupName;
 	this->_initialSubgroupName=initialSubgroupName;
@@ -54,7 +65,12 @@ void ModifyStudentsSubgroupForm::ok()
 	QString groupName=groupNameLineEdit->text();
 	
 	if(this->_initialSubgroupName!=subgroupName && gt.rules.searchStudentsSet(subgroupName)!=NULL){
-		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Name existing - please choose another"));
+		QMessageBox::information(this, QObject::tr("FET information"), 
+		 QObject::tr("Name exists. If you would like to make more groups to contain a subgroup (overlapping groups),"
+ 		 " please remove current subgroup (FET will unfortunately remove all related activities and constraints)"
+		 " and add a new subgroup with desired name in current group."
+ 		 " I know this is a not an elegant procedure, I'll try to fix that in the future."));
+		
 		return;
 	}
 
