@@ -19,8 +19,19 @@
 
 #include <qlineedit.h>
 
+#include <QDesktopWidget>
+
+#include <QMessageBox>
+
 ModifyStudentsYearForm::ModifyStudentsYearForm(const QString& initialYearName, int initialNumberOfStudents)
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	this->_initialYearName=initialYearName;
 	this->_initialNumberOfStudents=initialNumberOfStudents;
 	numberSpinBox->setValue(initialNumberOfStudents);
