@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Lalescu Liviu <liviu@lalescu.ro>, (C) 2003
+// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -26,6 +26,11 @@ public:
 	void removeSubject();
 	void renameSubject();
 	void sortSubjects();
+	
+	void subjectChanged(int index);
+	
+	void activateSubject();
+	void deactivateSubject();
 };
 
 #endif
