@@ -10,26 +10,39 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
 #include "subjecttagsform.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 #include "studentsset.h"
 #include "teacher.h"
 #include "subject.h"
 #include "subjecttag.h"
 
-#include <qlistbox.h>
+#include <q3listbox.h>
 #include <qinputdialog.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+
+#include <QDesktopWidget>
+
+#include <QMessageBox>
 
 SubjectTagsForm::SubjectTagsForm()
  : SubjectTagsForm_template()
 {
+	//setWindowFlags(Qt::Window);
+	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);
+
 	subjectTagsListBox->clear();
-	for(SubjectTag* sbt=gt.rules.subjectTagsList.first(); sbt; sbt=gt.rules.subjectTagsList.next())
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* sbt=gt.rules.subjectTagsList[i];
 		subjectTagsListBox->insertItem(sbt->name);
+	}
 		
 	if(subjectTagsListBox->count()>0){
 		subjectTagsListBox->setCurrentItem(0);
@@ -135,8 +148,10 @@ void SubjectTagsForm::sortSubjectTags()
 	gt.rules.sortSubjectTagsAlphabetically();
 
 	subjectTagsListBox->clear();
-	for(SubjectTag* sbt=gt.rules.subjectTagsList.first(); sbt; sbt=gt.rules.subjectTagsList.next())
-		subjectTagsListBox->insertItem(sbt->name);	
+	for(int i=0; i<gt.rules.subjectTagsList.size(); i++){
+		SubjectTag* sbt=gt.rules.subjectTagsList[i];
+		subjectTagsListBox->insertItem(sbt->name);
+	}
 }
 
 void SubjectTagsForm::subjectTagChanged(int index)
@@ -175,3 +190,11 @@ void SubjectTagsForm::deactivateSubjectTag()
 	int count=gt.rules.deactivateSubjectTag(text);
 	QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("De-activated a number of %1 activities").arg(count));
 }
+
+void SubjectTagsForm::help()
+{
+	QMessageBox::information(this, QObject::tr("FET help on subject tags"), 
+	 QObject::tr("Subject tag is a field which can be used or not, depending on your wish (optional field)."
+	 " It is designed to help you with some constraints. Each activity has a possible empty subject tag"
+	 " (if you don't use subject tags, it will be empty)"));
+}
