@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Lalescu Liviu <liviu@lalescu.ro>, (C) 2005
+// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2005
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -26,6 +26,13 @@ public:
 	void removeSubjectTag();
 	void renameSubjectTag();
 	void sortSubjectTags();
+	
+	void subjectTagChanged(int index);
+	
+	void activateSubjectTag();
+	void deactivateSubjectTag();
+	
+	void help();
 };
 
 #endif
