@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed May 14 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -30,6 +30,8 @@ public:
 	void updateTeachersTimetableTable();
 	
 	void detailActivity(int row, int col);
+	
+	void lock();
 };
 
 #endif
